@@ -19,25 +19,27 @@
 #
 """Weblate API client library."""
 
+from copy import copy
 from urllib.parse import urlencode, urlparse
+
+import dateutil.parser
 import requests
 
-__version__ = "1.1"
+__version__ = "1.2"
 
 URL = "https://weblate.org/"
 DEVEL_URL = "https://github.com/WeblateOrg/wlc"
 API_URL = "http://127.0.0.1:8000/api/"
 USER_AGENT = "wlc/{0}".format(__version__)
 LOCALHOST_NETLOC = "127.0.0.1"
+TIMESTAMPS = {"last_change"}
 
 
 class WeblateException(Exception):
-
     """Generic error."""
 
 
 class Weblate(object):
-
     """Weblate API wrapper object."""
 
     def __init__(self, key="", url=API_URL, config=None):
@@ -80,12 +82,10 @@ class Weblate(object):
         r = self.invoke_request(method, path, params, files)
 
         try:
-            result = r.json()
+            return r.json()
         except ValueError:
             raise WeblateException("Server returned invalid JSON")
 
-        return result
-
     def invoke_request(self, method, path, params=None, files=None):
         """Construct request object."""
         if not path.startswith("http"):
@@ -118,7 +118,7 @@ class Weblate(object):
         return self.request("get", path)
 
     def list_factory(self, path, parser):
-        """Wrapper for listing objects."""
+        """Listing object wrapper."""
         while path is not None:
             data = self.get(path)
             for item in data["results"]:
@@ -181,22 +181,15 @@ class Weblate(object):
         """Cheks if it should verify ssl certificates."""
         url = urlparse(path)
         is_localhost = url.netloc.startswith(LOCALHOST_NETLOC)
-        verify_ssl = url.scheme == "https" and (not is_localhost)
-        return verify_ssl
+        return url.scheme == "https" and (not is_localhost)
 
 
 class LazyObject(dict):
-
     """Object which supports deferred loading."""
 
-    _params = ()
-    _mappings = {}
-    _url = None
-    weblate = None
-    _loaded = False
-    _data = None
-    _attribs = None
-    _id = "url"
+    PARAMS = ()
+    MAPPINGS = {}
+    ID = "url"
 
     def __init__(self, weblate, url, **kwargs):
         """Construct object for given Weblate instance."""
@@ -204,21 +197,27 @@ class LazyObject(dict):
         self.weblate = weblate
         self._url = url
         self._data = {}
+        self._loaded = False
         self._attribs = {}
         self._load_params(**kwargs)
         self._load_params(url=url)
 
+    def get_data(self):
+        return copy(self._data)
+
     def _load_params(self, **kwargs):
-        for param in self._params:
+        for param in self.PARAMS:
             if param in kwargs:
                 value = kwargs[param]
-                if value is not None and param in self._mappings:
+                if value is not None and param in self.MAPPINGS:
                     if isinstance(value, str):
-                        self._data[param] = self._mappings[param](
+                        self._data[param] = self.MAPPINGS[param](
                             self.weblate, url=value
                         )
                     else:
-                        self._data[param] = self._mappings[param](self.weblate, **value)
+                        self._data[param] = self.MAPPINGS[param](self.weblate, **value)
+                elif value is not None and param in TIMESTAMPS:
+                    self._data[param] = dateutil.parser.parse(value)
                 else:
                     self._data[param] = value
                 del kwargs[param]
@@ -239,7 +238,7 @@ class LazyObject(dict):
         self._loaded = True
 
     def __getattr__(self, name):
-        if name not in self._params:
+        if name not in self.PARAMS:
             raise AttributeError(name)
         if name not in self._data:
             self.refresh()
@@ -249,42 +248,34 @@ class LazyObject(dict):
         return self.__getattr__(name)
 
     def __len__(self):
-        return len(self._params)
+        return len(self.PARAMS)
 
     def keys(self):
         """Return list of attributes."""
-        return self._params
+        return self.PARAMS
 
     def items(self):
         """Iterator over attributes."""
-        for key in self._params:
+        for key in self.PARAMS:
             yield key, self.__getattr__(key)
 
     def to_value(self):
         """Return identifier for the object."""
-        self.ensure_loaded(self._id)
-        return self.__getattr__(self._id)
+        self.ensure_loaded(self.ID)
+        return self.__getattr__(self.ID)
 
 
 class Language(LazyObject):
-
     """Language object."""
 
-    _params = (
-        "url",
-        "web_url",
-        "code",
-        "name",
-        "direction",
-    )
-    _id = "code"
+    PARAMS = ("url", "web_url", "code", "name", "direction")
+    ID = "code"
 
 
 class LanguageStats(LazyObject):
-
     """Language object."""
 
-    _params = (
+    PARAMS = (
         "total",
         "code",
         "translated_words",
@@ -294,11 +285,10 @@ class LanguageStats(LazyObject):
         "total_words",
         "words_percent",
     )
-    _id = "code"
+    ID = "code"
 
 
 class RepoMixin(object):
-
     """Repository mixin providing generic repository wide operations."""
 
     def _get_repo_url(self):
@@ -327,10 +317,9 @@ class RepoMixin(object):
 
 
 class ProjectRepository(LazyObject, RepoMixin):
-
     """Repository object."""
 
-    _params = ("url", "needs_commit", "needs_merge", "needs_push")
+    PARAMS = ("url", "needs_commit", "needs_merge", "needs_push")
 
     def _get_repo_url(self):
         """Return repository url."""
@@ -338,10 +327,9 @@ class ProjectRepository(LazyObject, RepoMixin):
 
 
 class Repository(ProjectRepository):
-
     """Repository object."""
 
-    _params = (
+    PARAMS = (
         "url",
         "needs_commit",
         "needs_merge",
@@ -353,24 +341,22 @@ class Repository(ProjectRepository):
 
 
 class RepoObjectMixin(RepoMixin):
-
     """Repository mixin."""
 
-    _repository_class = ProjectRepository
+    REPOSITORY_CLASS = ProjectRepository
 
     def repository(self):
         """Return repository object."""
         data = self.weblate.get(self._get_repo_url())
-        return self._repository_class(weblate=self.weblate, **data)
+        return self.REPOSITORY_CLASS(weblate=self.weblate, **data)
 
 
 class Project(LazyObject, RepoObjectMixin):
-
     """Project object."""
 
-    _params = ("url", "web_url", "name", "slug", "web", "source_language")
-    _id = "slug"
-    _mappings = {"source_language": Language}
+    PARAMS = ("url", "web_url", "name", "slug", "web", "source_language")
+    ID = "slug"
+    MAPPINGS = {"source_language": Language}
 
     def list(self):
         """List components in the project."""
@@ -378,9 +364,15 @@ class Project(LazyObject, RepoObjectMixin):
         return self.weblate.list_components(self._attribs["components_list_url"])
 
     def statistics(self):
-        """Return statistics for component."""
+        """Return statistics for translation."""
         self.ensure_loaded("statistics_url")
-        url = self._attribs["statistics_url"]
+        data = self.weblate.get(self._attribs["statistics_url"])
+        return Statistics(weblate=self.weblate, **data)
+
+    def languages(self):
+        """Return language statistics for component."""
+        self.ensure_loaded("languages_url")
+        url = self._attribs["languages_url"]
         return [
             LanguageStats(self.weblate, url, **item) for item in self.weblate.get(url)
         ]
@@ -390,12 +382,14 @@ class Project(LazyObject, RepoObjectMixin):
         self.ensure_loaded("changes_list_url")
         return self.weblate.list_changes(self._attribs["changes_list_url"])
 
+    def delete(self):
+        self.weblate.raw_request("delete", self._url)
+
 
 class Component(LazyObject, RepoObjectMixin):
-
     """Component object."""
 
-    _params = (
+    PARAMS = (
         "url",
         "web_url",
         "name",
@@ -412,9 +406,9 @@ class Component(LazyObject, RepoObjectMixin):
         "license",
         "license_url",
     )
-    _id = "slug"
-    _mappings = {"project": Project}
-    _repository_class = Repository
+    ID = "slug"
+    MAPPINGS = {"project": Project}
+    REPOSITORY_CLASS = Repository
 
     def list(self):
         """List translations in the component."""
@@ -424,7 +418,9 @@ class Component(LazyObject, RepoObjectMixin):
     def statistics(self):
         """Return statistics for component."""
         self.ensure_loaded("statistics_url")
-        return self.weblate.list_factory(self._attribs["statistics_url"], Statistics)
+        return self.weblate.list_factory(
+            self._attribs["statistics_url"], TranslationStatistics
+        )
 
     def _get_lock_url(self):
         self.ensure_loaded("lock_url")
@@ -447,12 +443,14 @@ class Component(LazyObject, RepoObjectMixin):
         self.ensure_loaded("changes_list_url")
         return self.weblate.list_changes(self._attribs["changes_list_url"])
 
+    def delete(self):
+        self.weblate.raw_request("delete", self._url)
+
 
 class Translation(LazyObject, RepoObjectMixin):
-
     """Translation object."""
 
-    _params = (
+    PARAMS = (
         "url",
         "web_url",
         "language",
@@ -479,9 +477,9 @@ class Translation(LazyObject, RepoObjectMixin):
         "last_change",
         "last_author",
     )
-    _id = "language_code"
-    _mappings = {"language": Language, "component": Component}
-    _repository_class = Repository
+    ID = "language_code"
+    MAPPINGS = {"language": Language, "component": Component}
+    REPOSITORY_CLASS = Repository
 
     def list(self):
         """API compatibility method, returns self."""
@@ -492,7 +490,7 @@ class Translation(LazyObject, RepoObjectMixin):
         """Return statistics for translation."""
         self.ensure_loaded("statistics_url")
         data = self.weblate.get(self._attribs["statistics_url"])
-        return Statistics(weblate=self.weblate, **data)
+        return TranslationStatistics(weblate=self.weblate, **data)
 
     def changes(self):
         """List changes in the project."""
@@ -512,21 +510,20 @@ class Translation(LazyObject, RepoObjectMixin):
         self.ensure_loaded("file_url")
         url = self._attribs["file_url"]
         files = {"file": file}
-        params = None
 
         if overwrite:
             kwargs["overwrite"] = "yes"
 
         return self.weblate.request("post", url, files=files, params=kwargs)
 
+    def delete(self):
+        self.weblate.raw_request("delete", self._url)
+
 
 class Statistics(LazyObject):
-
     """Statistics object."""
 
-    _params = (
-        "last_author",
-        "code",
+    PARAMS = (
         "failing_percent",
         "url",
         "translated_percent",
@@ -535,6 +532,7 @@ class Statistics(LazyObject):
         "translated_words",
         "url_translate",
         "fuzzy_percent",
+        "recent_changes",
         "translated",
         "fuzzy",
         "total",
@@ -543,11 +541,14 @@ class Statistics(LazyObject):
     )
 
 
-class Change(LazyObject):
+class TranslationStatistics(Statistics):
+    PARAMS = Statistics.PARAMS + ("code", "last_author")
 
+
+class Change(LazyObject):
     """Change object."""
 
-    _params = (
+    PARAMS = (
         "url",
         "unit",
         "translation",
@@ -556,5 +557,5 @@ class Change(LazyObject):
         "action_name",
         "target",
     )
-    _id = "id"
-    _mappings = {"translation": Translation, "component": Component}
+    ID = "id"
+    MAPPINGS = {"translation": Translation, "component": Component}
