@@ -20,8 +20,7 @@
 """Weblate API library, configuration."""
 
 import os.path
-
-from configparser import RawConfigParser, NoOptionError
+from configparser import NoOptionError, RawConfigParser
 
 from xdg.BaseDirectory import load_config_paths
 
@@ -31,7 +30,6 @@ __all__ = ["NoOptionError", "WeblateConfig"]
 
 
 class WeblateConfig(RawConfigParser):
-
     """Configuration parser wrapper with defaults."""
 
     def __init__(self, section="weblate"):
