@@ -18,15 +18,15 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Command line interface for Weblate."""
-import sys
-import json
 import csv
-from argparse import ArgumentParser
-import logging
 import http.client
+import json
+import logging
+import sys
+from argparse import ArgumentParser
 
 import wlc
-from wlc.config import WeblateConfig, NoOptionError
+from wlc.config import NoOptionError, WeblateConfig
 
 COMMANDS = {}
 
@@ -34,7 +34,7 @@ SORT_ORDER = []
 
 
 def register_command(command):
-    """Decorator to register command in command line interface."""
+    """Register command decorator in the command line interface."""
     COMMANDS[command.name] = command
     return command
 
@@ -384,6 +384,18 @@ class Show(ObjectCommand):
         self.print(self.get_object())
 
 
+@register_command
+class Delete(ObjectCommand):
+    """Delete object."""
+
+    name = "delete"
+    description = "Delete translation, component or project"
+
+    def run(self):
+        """Executor."""
+        self.get_object().delete()
+
+
 @register_command
 class List(ObjectCommand):
     """List object."""
@@ -523,7 +535,7 @@ class Stats(ObjectCommand):
         """Executor."""
         obj = self.get_object()
         if isinstance(obj, wlc.Project):
-            self.print(list(obj.statistics()))
+            self.print(obj.statistics())
         elif isinstance(obj, wlc.Component):
             self.print(list(obj.statistics()))
         else:
@@ -601,7 +613,6 @@ class Download(TranslationCommand):
 
 @register_command
 class Upload(TranslationCommand):
-
     """Uploads translation file."""
 
     name = "upload"
@@ -627,7 +638,7 @@ class Upload(TranslationCommand):
         )
         parser.add_argument(
             "--method",
-            choices=("translate", "approve", "suggest", "fuzzy"),
+            choices=("translate", "approve", "suggest", "fuzzy", "replace"),
             default="translate",
         )
         parser.add_argument("--fuzzy", choices=("", "process", "approve"), default="")
