@@ -19,15 +19,16 @@
 #
 """Test command line interface."""
 
-from io import StringIO, BytesIO, TextIOWrapper
 import json
-import sys
-from tempfile import NamedTemporaryFile
 import os
+import sys
+from io import BytesIO, StringIO, TextIOWrapper
+from tempfile import NamedTemporaryFile
 
 import wlc
-from wlc.main import main
 from wlc.config import WeblateConfig
+from wlc.main import main
+
 from .test_base import APITest
 
 TEST_CONFIG = os.path.join(os.path.dirname(__file__), "test_data", "wlc")
@@ -55,13 +56,12 @@ def execute(args, settings=None, stdout=None, stdin=None, expected=0):
         sys.stdout = backup
         sys.stderr = backup_err
     result = output.buffer.getvalue()
-    if not result:
-        result = output.getvalue()
-    return result
+    if result:
+        return result
+    return output.getvalue()
 
 
 class TestSettings(APITest):
-
     """Test settings handling."""
 
     def test_commandline(self):
@@ -137,7 +137,6 @@ class TestSettings(APITest):
 
 
 class TestOutput(APITest):
-
     """Test output formatting."""
 
     def test_version_text(self):
@@ -184,7 +183,6 @@ class TestOutput(APITest):
 
 
 class TestCommands(APITest):
-
     """Individual command tests."""
 
     def test_version_bare(self):
@@ -232,6 +230,17 @@ class TestCommands(APITest):
         output = execute(["show", "hello/weblate/cs"])
         self.assertIn("/hello/weblate/cs/", output)
 
+    def test_delete(self):
+        """Project delete."""
+        output = execute(["delete", "hello"])
+        self.assertEqual("", output)
+
+        output = execute(["delete", "hello/weblate"])
+        self.assertEqual("", output)
+
+        output = execute(["delete", "hello/weblate/cs"])
+        self.assertEqual("", output)
+
     def test_commit(self):
         """Project commit."""
         output = execute(["commit", "hello"])
