@@ -18,15 +18,14 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Test the module."""
-from .test_base import APITest
-
 import io
 
-from wlc import Weblate, WeblateException, Project, Component, Translation, Change
+from wlc import Change, Component, Project, Translation, Weblate, WeblateException
+
+from .test_base import APITest
 
 
 class WeblateErrorTest(APITest):
-
     """Testing error handling."""
 
     def test_nonexisting(self):
@@ -74,7 +73,6 @@ class WeblateErrorTest(APITest):
 
 
 class WeblateTest(APITest):
-
     """Testing of Weblate class."""
 
     def test_languages(self):
@@ -110,7 +108,6 @@ class WeblateTest(APITest):
 
 
 class ObjectTest(object):
-
     """Base class for objects testing."""
 
     _name = None
@@ -193,9 +190,16 @@ class ObjectTest(object):
             {"result": False, "detail": "Push is disabled for Hello/Weblate."},
         )
 
+    def test_data(self):
+        obj = self.get()
+        self.assertIsNotNone(obj.get_data())
+
+    def test_delete(self):
+        obj = self.get()
+        self.assertIsNone(obj.delete())
+
 
 class ProjectTest(ObjectTest, APITest):
-
     """Project object tests."""
 
     _name = "hello"
@@ -211,14 +215,19 @@ class ProjectTest(ObjectTest, APITest):
         self.assertEqual(len(lst), 2)
         self.assertIsInstance(lst[0], Component)
 
+    def test_languages(self):
+        """Component statistics test."""
+        obj = self.get()
+        self.assertEqual(2, len(list(obj.languages())))
+
     def test_statistics(self):
         """Component statistics test."""
         obj = self.get()
-        self.assertEqual(2, len(list(obj.statistics())))
+        stats = obj.statistics()
+        self.assertEqual(stats["name"], "Hello")
 
 
 class ComponentTest(ObjectTest, APITest):
-
     """Component object tests."""
 
     _name = "hello/weblate"
@@ -256,7 +265,6 @@ class ComponentTest(ObjectTest, APITest):
 
 
 class TranslationTest(ObjectTest, APITest):
-
     """Translation object tests."""
 
     _name = "hello/weblate/cs"
